/**
 *
 * @file chameleon_tasks_d.h
 *
 * @copyright 2009-2014 The University of Tennessee and The University of
 *                      Tennessee Research Foundation. All rights reserved.
 * @copyright 2012-2021 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 ***
 *
 * @brief Chameleon double elementary tasks header
 *
 * @version 1.1.0
 * @comment This file has been automatically generated
 *          from Plasma 2.5.0 for CHAMELEON 0.9.2
 * @author Jakub Kurzak
 * @author Hatem Ltaief
 * @author Azzam Haidar
 * @author Mathieu Faverge
 * @author Emmanuel Agullo
 * @author Cedric Castagnede
 * @author Florent Pruvost
 * @date 2020-10-12
 * @generated from /tmp/slackdce/slackrepo.gsXdbP/build_chameleon/chameleon-1.1.0/include/chameleon/tasks_z.h, normal z -> d, Sat May 10 04:39:46 2025
 *
 */
#ifndef _chameleon_tasks_d_h_
#define _chameleon_tasks_d_h_

/**
 *  Declarations of QUARK wrappers (called by CHAMELEON) - alphabetical order
 */
void INSERT_TASK_dlag2z_fake( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, int m, int n,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dasum( const RUNTIME_option_t *options,
                         cham_store_t storev, cham_uplo_t uplo, int M, int N,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_daxpy( const RUNTIME_option_t *options,
                        int M, double alpha,
                        const CHAM_desc_t *A, int Am, int An, int incA,
                        const CHAM_desc_t *B, int Bm, int Bn, int incB );
void INSERT_TASK_dbuild( const RUNTIME_option_t *options,
                         const CHAM_desc_t *A, int Am, int An,
                         void *user_data, void* user_build_callback );
void INSERT_TASK_dgeadd( const RUNTIME_option_t *options,
                         cham_trans_t trans, int m, int n, int nb,
                         double alpha, const CHAM_desc_t *A, int Am, int An,
                         double beta,  const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dgelqt( const RUNTIME_option_t *options,
                         int m, int n, int ib, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *T, int Tm, int Tn );
void INSERT_TASK_dgemv( const RUNTIME_option_t *options,
                        cham_trans_t trans, int m, int n,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                                                     const CHAM_desc_t *X, int Xm, int Xn, int incX,
                        double beta,  const CHAM_desc_t *Y, int Ym, int Yn, int incY );
void INSERT_TASK_dgemm( const RUNTIME_option_t *options,
                        cham_trans_t transA, cham_trans_t transB,
                        int m, int n, int k, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        const CHAM_desc_t *B, int Bm, int Bn,
                        double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dgeqrt( const RUNTIME_option_t *options,
                         int m, int n, int ib, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *T, int Tm, int Tn );
void INSERT_TASK_dgessm( const RUNTIME_option_t *options,
                         int m, int n, int k, int ib, int nb,
                         int *IPIV,
                         const CHAM_desc_t *L, int Lm, int Ln,
                         const CHAM_desc_t *D, int Dm, int Dn,
                         const CHAM_desc_t *A, int Am, int An );
void INSERT_TASK_dgessq( const RUNTIME_option_t *options,
                         cham_store_t storev, int m, int n,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *SCALESUMSQ, int SCALESUMSQm, int SCALESUMSQn );
void INSERT_TASK_dgetrf( const RUNTIME_option_t *options,
                         int m, int n, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         int *IPIV,
                         cham_bool_t check_info, int iinfo );
void INSERT_TASK_dgetrf_incpiv( const RUNTIME_option_t *options,
                                int m, int n, int ib, int nb,
                                const CHAM_desc_t *A, int Am, int An,
                                const CHAM_desc_t *L, int Lm, int Ln,
                                int *IPIV,
                                cham_bool_t check_info, int iinfo );
void INSERT_TASK_dgetrf_nopiv( const RUNTIME_option_t *options,
                               int m, int n, int ib, int nb,
                               const CHAM_desc_t *A, int Am, int An, int iinfo );
void INSERT_TASK_dhe2ge( const RUNTIME_option_t *options,
                         cham_uplo_t uplo,
                         int m, int n, int mb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dsymm( const RUNTIME_option_t *options,
                        cham_side_t side, cham_uplo_t uplo,
                        int m, int n, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        const CHAM_desc_t *B, int Bm, int Bn,
                        double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyr2k( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, cham_trans_t trans,
                         int n, int k, int nb,
                         double alpha, const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn,
                         double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyrfb( const RUNTIME_option_t *options,
                         cham_uplo_t uplo,
                         int n, int k, int ib, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *T, int Tm, int Tn,
                         const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyrk( const RUNTIME_option_t *options,
                        cham_uplo_t uplo, cham_trans_t trans,
                        int n, int k, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyssq( const RUNTIME_option_t *options,
                         cham_store_t storev, cham_uplo_t uplo, int n,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *SCALESUMSQ, int SCALESUMSQm, int SCALESUMSQn );
void INSERT_TASK_dlacpy( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, int m, int n, int mb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlacpyx( const RUNTIME_option_t *options,
                          cham_uplo_t uplo, int m, int n, int mb,
                          int displA, const CHAM_desc_t *A, int Am, int An,
                          int displB, const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlange( const RUNTIME_option_t *options,
                         cham_normtype_t norm, int M, int N, int NB,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlange_max( const RUNTIME_option_t *options,
                             const CHAM_desc_t *A, int Am, int An,
                             const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlansy( const RUNTIME_option_t *options,
                         cham_normtype_t norm, cham_uplo_t uplo, int N, int NB,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlansy( const RUNTIME_option_t *options,
                         cham_normtype_t norm, cham_uplo_t uplo, int N, int NB,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlantr( const RUNTIME_option_t *options,
                         cham_normtype_t norm, cham_uplo_t uplo, cham_diag_t diag,
                         int M, int N, int NB,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlascal( const RUNTIME_option_t *options,
                          cham_uplo_t uplo,
                          int m, int n, int nb,
                          double alpha,
                          const CHAM_desc_t *A, int Am, int An );
void INSERT_TASK_dlaset( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, int n1, int n2,
                         double alpha, double beta,
                         const CHAM_desc_t *tileA, int tileAm, int tileAn );
void INSERT_TASK_dlaset2( const RUNTIME_option_t *options,
                          cham_uplo_t uplo, int n1, int n2, double alpha,
                          const CHAM_desc_t *tileA, int tileAm, int tileAn );
void INSERT_TASK_dlatro( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, cham_trans_t trans, int m, int n, int mb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dlauum( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, int n, int nb,
                         const CHAM_desc_t *A, int Am, int An );
void INSERT_TASK_dplgsy( const RUNTIME_option_t *options,
                         double bump, int m, int n, const CHAM_desc_t *A, int Am, int An,
                         int bigM, int m0, int n0, unsigned long long int seed );
void INSERT_TASK_dplgsy( const RUNTIME_option_t *options,
                         double bump, int m, int n, const CHAM_desc_t *A, int Am, int An,
                         int bigM, int m0, int n0, unsigned long long int seed );
void INSERT_TASK_dplrnt( const RUNTIME_option_t *options,
                         int m, int n, const CHAM_desc_t *A, int Am, int An,
                         int bigM, int m0, int n0, unsigned long long int seed );
void INSERT_TASK_dplssq( const RUNTIME_option_t *options,
                         cham_store_t storev, int M, int N,
                         const CHAM_desc_t *SCALESUMSQ, int SCALESUMSQm, int SCALESUMSQn,
                         const CHAM_desc_t *SCLSSQ,     int SCLSSQm,     int SCLSSQn );
void INSERT_TASK_dplssq2( const RUNTIME_option_t *options, int N,
                          const CHAM_desc_t *RESULT, int RESULTm, int RESULTn );
void INSERT_TASK_dpotrf( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, int n, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         int iinfo );
void INSERT_TASK_dssssm( const RUNTIME_option_t *options,
                         int m1, int n1, int m2, int n2, int k, int ib, int nb,
                         const CHAM_desc_t *A1, int A1m, int A1n,
                         const CHAM_desc_t *A2, int A2m, int A2n,
                         const CHAM_desc_t *L1, int L1m, int L1n,
                         const CHAM_desc_t *L2, int L2m, int L2n,
                         const int *IPIV );
void INSERT_TASK_dsymm( const RUNTIME_option_t *options,
                        cham_side_t side, cham_uplo_t uplo,
                        int m, int n, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        const CHAM_desc_t *B, int Bm, int Bn,
                        double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyr2k( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, cham_trans_t trans,
                         int n, int k, int nb,
                         double alpha, const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn,
                         double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyrk( const RUNTIME_option_t *options,
                        cham_uplo_t uplo, cham_trans_t trans,
                        int n, int k, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        double beta, const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dsyssq( const RUNTIME_option_t *options,
                         cham_store_t storev, cham_uplo_t uplo, int n,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *SCALESUMSQ, int SCALESUMSQm, int SCALESUMSQn );
void INSERT_TASK_dsytrf_nopiv( const RUNTIME_option_t *options,
                               cham_uplo_t uplo, int n, int nb,
                               const CHAM_desc_t *A, int Am, int An,
                               int iinfo );
void INSERT_TASK_dtplqt( const RUNTIME_option_t *options,
                         int m, int n, int l, int ib, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn,
                         const CHAM_desc_t *T, int Tm, int Tn );
void INSERT_TASK_dtpmlqt( const RUNTIME_option_t *options,
                          cham_side_t side, cham_trans_t trans,
                          int M, int N, int K, int L, int ib, int nb,
                          const CHAM_desc_t *V, int Vm, int Vn,
                          const CHAM_desc_t *T, int Tm, int Tn,
                          const CHAM_desc_t *A, int Am, int An,
                          const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dtpmqrt( const RUNTIME_option_t *options,
                          cham_side_t side, cham_trans_t trans,
                          int m, int n, int k, int l, int ib, int nb,
                          const CHAM_desc_t *V, int Vm, int Vn,
                          const CHAM_desc_t *T, int Tm, int Tn,
                          const CHAM_desc_t *A, int Am, int An,
                          const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dtpqrt( const RUNTIME_option_t *options,
                         int m, int n, int l, int ib, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn,
                         const CHAM_desc_t *T, int Tm, int Tn );
void INSERT_TASK_dtradd( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, cham_trans_t trans, int m, int n, int nb,
                         double alpha, const CHAM_desc_t *A, int Am, int An,
                         double beta,  const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dtrasm( const RUNTIME_option_t *options,
                         cham_store_t storev, cham_uplo_t uplo, cham_diag_t diag, int M, int N,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dtrmm( const RUNTIME_option_t *options,
                        cham_side_t side, cham_uplo_t uplo, cham_trans_t transA, cham_diag_t diag,
                        int m, int n, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dtrsm( const RUNTIME_option_t *options,
                        cham_side_t side, cham_uplo_t uplo, cham_trans_t transA, cham_diag_t diag,
                        int m, int n, int nb,
                        double alpha, const CHAM_desc_t *A, int Am, int An,
                        const CHAM_desc_t *B, int Bm, int Bn );
void INSERT_TASK_dtrssq( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, cham_diag_t diag,
                         int m, int n,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *SCALESUMSQ, int SCALESUMSQm, int SCALESUMSQn );
void INSERT_TASK_dtrtri( const RUNTIME_option_t *options,
                         cham_uplo_t uplo, cham_diag_t diag, int n, int nb,
                         const CHAM_desc_t *A, int Am, int An,

                         int iinfo );
void INSERT_TASK_dtsmlq_hetra1( const RUNTIME_option_t *options,
                                cham_side_t side, cham_trans_t trans,
                                int m1, int n1, int m2, int n2, int k, int ib, int nb,
                                const CHAM_desc_t *A1, int A1m, int A1n,
                                const CHAM_desc_t *A2, int A2m, int A2n,
                                const CHAM_desc_t *V, int Vm, int Vn,
                                const CHAM_desc_t *T, int Tm, int Tn );
void INSERT_TASK_dtsmqr_hetra1( const RUNTIME_option_t *options,
                                cham_side_t side, cham_trans_t trans,
                                int m1, int n1, int m2, int n2, int k, int ib, int nb,
                                const CHAM_desc_t *A1, int A1m, int A1n,
                                const CHAM_desc_t *A2, int A2m, int A2n,
                                const CHAM_desc_t *V, int Vm, int Vn,
                                const CHAM_desc_t *T, int Tm, int Tn );
void INSERT_TASK_dtstrf( const RUNTIME_option_t *options,
                         int m, int n, int ib, int nb,
                         const CHAM_desc_t *U, int Um, int Un,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *L, int Lm, int Ln,
                         int *IPIV,
                         cham_bool_t check_info, int iinfo );
void INSERT_TASK_dormlq( const RUNTIME_option_t *options,
                         cham_side_t side, cham_trans_t trans,
                         int m, int n, int ib,  int nb, int k,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *T, int Tm, int Tn,
                         const CHAM_desc_t *C, int Cm, int Cn );
void INSERT_TASK_dormqr( const RUNTIME_option_t *options,
                         cham_side_t side, cham_trans_t trans,
                         int m, int n, int k, int ib, int nb,
                         const CHAM_desc_t *A, int Am, int An,
                         const CHAM_desc_t *T, int Tm, int Tn,
                         const CHAM_desc_t *C, int Cm, int Cn );

/**
 * Keep these insert_task for retro-compatibility
 */
static inline void
INSERT_TASK_dtslqt( const RUNTIME_option_t *options,
                    int m, int n, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    INSERT_TASK_dtplqt( options, m, n, 0, ib, nb,
                        A1, A1m, A1n,
                        A2, A2m, A2n,
                        T,  Tm,  Tn );
}

static inline void
INSERT_TASK_dtsqrt( const RUNTIME_option_t *options,
                    int m, int n, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    INSERT_TASK_dtpqrt( options, m, n, 0, ib, nb,
                        A1, A1m, A1n,
                        A2, A2m, A2n,
                        T,  Tm,  Tn );
}

static inline void
INSERT_TASK_dttlqt( const RUNTIME_option_t *options,
                    int m, int n, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    INSERT_TASK_dtplqt( options, m, n, n, ib, nb,
                        A1, A1m, A1n,
                        A2, A2m, A2n,
                        T,  Tm,  Tn );
}

static inline void
INSERT_TASK_dttqrt( const RUNTIME_option_t *options,
                    int m, int n, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    INSERT_TASK_dtpqrt( options, m, n, m, ib, nb,
                        A1, A1m, A1n,
                        A2, A2m, A2n,
                        T,  Tm,  Tn );
}

static inline void
INSERT_TASK_dtsmlq( const RUNTIME_option_t *options,
                    cham_side_t side, cham_trans_t trans,
                    int m1, int n1, int m2, int n2, int k, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *V, int Vm, int Vn,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    (void)m1;
    (void)n1;
    INSERT_TASK_dtpmlqt( options, side, trans, m2, n2, k, 0, ib, nb,
                         V, Vm, Vn, T, Tm, Tn,
                         A1, A1m, A1n, A2, A2m, A2n );
}

static inline void
INSERT_TASK_dtsmqr( const RUNTIME_option_t *options,
                    cham_side_t side, cham_trans_t trans,
                    int m1, int n1, int m2, int n2, int k, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *V, int Vm, int Vn,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    (void)m1;
    (void)n1;
    INSERT_TASK_dtpmqrt( options, side, trans, m2, n2, k, 0, ib, nb,
                         V, Vm, Vn, T, Tm, Tn,
                         A1, A1m, A1n, A2, A2m, A2n );
}

static inline void
INSERT_TASK_dttmlq( const RUNTIME_option_t *options,
                    cham_side_t side, cham_trans_t trans,
                    int m1, int n1, int m2, int n2, int k, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *V, int Vm, int Vn,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    (void)m1;
    (void)n1;
    INSERT_TASK_dtpmlqt( options, side, trans, m2, n2, k, n2, ib, nb,
                         V, Vm, Vn, T, Tm, Tn,
                         A1, A1m, A1n, A2, A2m, A2n );
}

static inline void
INSERT_TASK_dttmqr( const RUNTIME_option_t *options,
                    cham_side_t side, cham_trans_t trans,
                    int m1, int n1, int m2, int n2, int k, int ib, int nb,
                    const CHAM_desc_t *A1, int A1m, int A1n,
                    const CHAM_desc_t *A2, int A2m, int A2n,
                    const CHAM_desc_t *V, int Vm, int Vn,
                    const CHAM_desc_t *T, int Tm, int Tn )
{
    (void)m1;
    (void)n1;
    INSERT_TASK_dtpmqrt( options, side, trans, m2, n2, k, m2, ib, nb,
                         V, Vm, Vn, T, Tm, Tn,
                         A1, A1m, A1n, A2, A2m, A2n );
}

/**
 * Gram prototype
 */
void INSERT_TASK_dgram( const RUNTIME_option_t *options,
                        cham_uplo_t uplo,
                        int m, int n, int mt, int nt,
                        const CHAM_desc_t *Di, int Dim, int Din,
                        const CHAM_desc_t *Dj, int Djm, int Djn,
                        const CHAM_desc_t *D, int Dm, int Dn,
                        CHAM_desc_t *A, int Am, int An);

#endif /* _chameleon_tasks_d_h_ */
