/**
 *
 * @file coreblas_d.h
 *
 * @copyright 2009-2014 The University of Tennessee and The University of
 *                      Tennessee Research Foundation. All rights reserved.
 * @copyright 2012-2021 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 ***
 *
 * @brief Chameleon CPU double kernels header
 *
 * @version 1.1.0
 * @comment This file has been automatically generated
 *          from Plasma 2.5.0 for CHAMELEON 0.9.2
 * @author Jakub Kurzak
 * @author Hatem Ltaief
 * @author Azzam Haidar
 * @author Mathieu Faverge
 * @author Emmanuel Agullo
 * @author Cedric Castagnede
 * @author Florent Pruvost
 * @date 2020-10-12
 * @generated from /tmp/slackdce/slackrepo.gsXdbP/build_chameleon/chameleon-1.1.0/coreblas/include/coreblas/coreblas_z.h, normal z -> d, Sat May 10 04:39:42 2025
 *
 */
#ifndef _coreblas_d_h_
#define _coreblas_d_h_

/**
 *  Declarations of serial kernels - alphabetical order
 */
void CORE_dlag2z_fake( cham_uplo_t uplo, int M, int N,
                  const double          *A, int lda,
                  double *B, int ldb );
void CORE_dasum(cham_store_t storev, cham_uplo_t uplo, int M, int N,
                 const double *A, int lda, double *work);
int CORE_daxpy(int M, double alpha,
               const double *A, int incA,
                     double *B, int incB);
int CORE_dgeadd(cham_trans_t trans, int M, int N,
                      double alpha,
                const double *A, int LDA,
                      double beta,
                      double *B, int LDB);
int CORE_dlascal( cham_uplo_t uplo, int m, int n,
              double alpha, double *A, int lda );
int  CORE_dgelqt(int M, int N, int IB,
                 double *A, int LDA,
                 double *T, int LDT,
                 double *TAU,
                 double *WORK);
void CORE_dgemm(cham_trans_t transA, cham_trans_t transB,
                int M, int N, int K,
                double alpha, const double *A, int LDA,
                                          const double *B, int LDB,
                double beta,        double *C, int LDC);
void CORE_dgemv(cham_trans_t trans, int M, int N,
                double alpha, const double *A, int LDA,
                                             const double *x, int incX,
                double beta,        double *y, int incY);
int  CORE_dgeqrt(int M, int N, int IB,
                 double *A, int LDA,
                 double *T, int LDT,
                 double *TAU, double *WORK);
int CORE_dgesplit(cham_side_t side, cham_diag_t diag,
                  int M, int N,
                  double *A, int LDA,
                  double *B, int LDB);
int  CORE_dgessm(int M, int N, int K, int IB,
                 const int *IPIV,
                 const double *L, int LDL,
                 double *A, int LDA);
int  CORE_dgessq(cham_store_t storev, int M, int N,
                 const double *A, int LDA,
                 double *sclssq);
int CORE_dgetf2_nopiv(int M, int N,
                  double *A, int LDA);
int  CORE_dgetrf(int M, int N,
                 double *A, int LDA,
                 int *IPIV, int *INFO);
int  CORE_dgetrf_incpiv(int M, int N, int IB,
                        double *A, int LDA,
                        int *IPIV, int *INFO);
int CORE_dgetrf_nopiv(int M, int N, int IB,
                      double *A, int LDA,
                      int *INFO);
int  CORE_dgetrf_reclap(int M, int N,
                        double *A, int LDA,
                        int *IPIV, int *info);
int  CORE_dgetrf_rectil(const CHAM_desc_t A, int *IPIV, int *info);
void CORE_dgetrip(int m, int n, double *A,
                  double *work);
void CORE_dhe2ge(cham_uplo_t uplo, int M, int N,
                 const double *A, int LDA,
                 double *B, int LDB);
void CORE_dsygst(int itype, cham_uplo_t uplo, int N,
                 double *A, int LDA,
                 double *B, int LDB, int *INFO);
void CORE_dsymm(cham_side_t side, cham_uplo_t uplo,
                int M, int N,
                double alpha, const double *A, int LDA,
                                          const double *B, int LDB,
                double beta,        double *C, int LDC);
void CORE_dsyrk(cham_uplo_t uplo, cham_trans_t trans,
                int N, int K,
                double alpha, const double *A, int LDA,
                double beta,        double *C, int LDC);
void CORE_dsyr2k(cham_uplo_t uplo, cham_trans_t trans,
                 int N, int K,
                 double alpha, const double *A, int LDA,
                                           const double *B, int LDB,
                 double beta,                    double *C, int LDC);
int  CORE_dsyssq(cham_store_t storev, cham_uplo_t uplo, int N,
                 const double *A, int LDA,
                 double *sclssq);
int  CORE_dsyrfb(cham_uplo_t uplo, int N, int K, int IB, int NB,
                 const double *A,    int LDA,
                 const double *T,    int LDT,
                       double *C,    int LDC,
                       double *WORK, int LDWORK);
void CORE_dlacpy(cham_uplo_t uplo, int M, int N,
                 const double *A, int LDA,
                       double *B, int LDB);
void CORE_dlange(cham_normtype_t norm, int M, int N,
                 const double *A, int LDA,
                 double *work, double *normA);
void CORE_dlansy(cham_normtype_t norm, cham_uplo_t uplo, int N,
                 const double *A, int LDA,
                 double *work, double *normA);
void CORE_dlansy(cham_normtype_t norm, cham_uplo_t uplo, int N,
                 const double *A, int LDA,
                 double *work, double *normA);
void CORE_dlantr(cham_normtype_t norm, cham_uplo_t uplo, cham_diag_t diag, int M, int N,
                 const double *A, int LDA,
                 double *work, double *normA);
int CORE_dlarfb_gemm(cham_side_t side, cham_trans_t trans, cham_dir_t direct, cham_store_t storev,
                     int M, int N, int K,
                     const double *V, int LDV,
                     const double *T, int LDT,
                           double *C, int LDC,
                           double *WORK, int LDWORK);
int CORE_dlarfx2(cham_side_t side, int N,
                 double V,
                 double TAU,
                 double *C1, int LDC1,
                 double *C2, int LDC2);
int CORE_dlarfx2c(cham_uplo_t uplo,
                  double V,
                  double TAU,
                  double *C1,
                  double *C2,
                  double *C3);
int CORE_dlarfx2ce(cham_uplo_t uplo,
                   double *V,
                   double *TAU,
                   double *C1,
                   double *C2,
                   double *C3);
void CORE_dlarfy(int N,
                 double *A, int LDA,
                 const double *V,
                 const double *TAU,
                 double *WORK);
void CORE_dlaset(cham_uplo_t uplo, int n1, int n2,
                 double alpha, double beta,
                 double *tileA, int ldtilea);
void CORE_dlaset2(cham_uplo_t uplo, int n1, int n2, double alpha,
                  double *tileA, int ldtilea);
void CORE_dlaswp(int N, double *A, int LDA,
                 int I1,  int I2, const int *IPIV, int INC);
int  CORE_dlaswp_ontile( CHAM_desc_t descA, int i1, int i2, const int *ipiv, int inc);
int  CORE_dlaswpc_ontile(CHAM_desc_t descA, int i1, int i2, const int *ipiv, int inc);
int  CORE_dlatro(cham_uplo_t uplo, cham_trans_t trans,
                 int M, int N,
                 const double *A, int LDA,
                       double *B, int LDB);
int CORE_dlatm1( int MODE, double COND, int IRSIGN, cham_dist_t DIST,
                 unsigned long long int seed,
                 double *D, int N );
void CORE_dlauum(cham_uplo_t uplo, int N, double *A, int LDA);
int CORE_dpamm(int op, cham_side_t side, cham_store_t storev,
               int M, int N, int K, int L,
               const double *A1, int LDA1,
                     double *A2, int LDA2,
               const double *V, int LDV,
                     double *W, int LDW);
int  CORE_dparfb(cham_side_t side, cham_trans_t trans, cham_dir_t direct, cham_store_t storev,
                 int M1, int N1, int M2, int N2, int K, int L,
                       double *A1, int LDA1,
                       double *A2, int LDA2,
                 const double *V, int LDV,
                 const double *T, int LDT,
                       double *WORK, int LDWORK);
int CORE_dpemv(cham_trans_t trans, cham_store_t storev,
               int M, int N, int L,
               double ALPHA,
               const double *A, int LDA,
               const double *X, int INCX,
               double BETA,
               double *Y, int INCY,
               double *WORK);
void CORE_dplgsy(double bump, int m, int n, double *A, int lda,
                 int bigM, int m0, int n0, unsigned long long int seed );
void CORE_dplgsy(double bump, int m, int n, double *A, int lda,
                 int bigM, int m0, int n0, unsigned long long int seed );
void CORE_dplrnt(int m, int n, double *A, int lda,
                 int bigM, int m0, int n0, unsigned long long int seed );
int CORE_dplssq( cham_store_t storev, int M, int N,
                 double *sclssqin, double *sclssqout );
int CORE_dplssq2( int N, double *sclssq );
void CORE_dpotrf(cham_uplo_t uplo, int N, double *A, int LDA, int *INFO);
void CORE_dshift(int s, int m, int n, int L,
                 double *A);
void CORE_dshiftw(int s, int cl, int m, int n, int L,
                  double *A, double *W);
int  CORE_dssssm(int M1, int N1, int M2, int N2, int K, int IB,
                       double *A1, int LDA1,
                       double *A2, int LDA2,
                 const double *L1, int LDL1,
                 const double *L2, int LDL2,
                 const int *IPIV);
void CORE_dsymm(cham_side_t side, cham_uplo_t uplo,
                int M, int N,
                double alpha, const double *A, int LDA,
                                          const double *B, int LDB,
                double beta,        double *C, int LDC);
void CORE_dsyrk(cham_uplo_t uplo, cham_trans_t trans,
                int N, int K,
                double alpha, const double *A, int LDA,
                double beta,        double *C, int LDC);
void CORE_dsyr2k(cham_uplo_t uplo, cham_trans_t trans,
                 int N, int K,
                 double alpha, const double *A, int LDA,
                                           const double *B, int LDB,
                 double beta,        double *C, int LDC);
int  CORE_dsyssq(cham_store_t storev, cham_uplo_t uplo, int N,
                 const double *A, int LDA,
                 double *sclssq);
int CORE_dsytf2_nopiv(cham_uplo_t uplo, int n, double *A, int lda);
int CORE_dtradd(cham_uplo_t uplo, cham_trans_t trans, int M, int N,
                      double alpha,
                const double *A, int LDA,
                      double beta,
                      double *B, int LDB);
void CORE_dtrasm(cham_store_t storev, cham_uplo_t uplo, cham_diag_t diag,
                 int M, int N,
                 const double *A, int lda, double *work);
void CORE_dtrmm(cham_side_t side, cham_uplo_t uplo,
                cham_trans_t transA, cham_diag_t diag,
                int M, int N,
                double alpha, const double *A, int LDA,
                                                double *B, int LDB);
void CORE_dtrsm(cham_side_t side, cham_uplo_t uplo,
                cham_trans_t transA, cham_diag_t diag,
                int M, int N,
                double alpha, const double *A, int LDA,
                                                double *B, int LDB);
int CORE_dtrssq(cham_uplo_t uplo, cham_diag_t diag, int M, int N,
                const double *A, int LDA,
                double *scale, double *sumsq);
void CORE_dtrtri(cham_uplo_t uplo, cham_diag_t diag, int N,
                 double *A, int LDA, int *info);
int  CORE_dtslqt(int M, int N, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 double *T, int LDT,
                 double *TAU, double *WORK);
int  CORE_dtsmlq(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 const double *V, int LDV,
                 const double *T, int LDT,
                 double *WORK, int LDWORK);
int CORE_dtsmlq_hetra1( cham_side_t side, cham_trans_t trans,
                        int m1, int n1, int m2, int n2,
                        int k, int ib,
                        double *A1, int lda1,
                        double *A2, int lda2,
                        const double *V, int ldv,
                        const double *T, int ldt,
                        double *WORK, int ldwork);
int  CORE_dtsmqr(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 const double *V, int LDV,
                 const double *T, int LDT,
                 double *WORK, int LDWORK);
int CORE_dtsmqr_hetra1( cham_side_t side, cham_trans_t trans,
                        int m1, int n1, int m2, int n2,
                        int k, int ib,
                        double *A1, int lda1,
                        double *A2, int lda2,
                        const double *V, int ldv,
                        const double *T, int ldt,
                        double *WORK, int ldwork);
int  CORE_dtsqrt(int M, int N, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 double *T, int LDT,
                 double *TAU, double *WORK);
int  CORE_dtstrf(int M, int N, int IB, int NB,
                 double *U, int LDU,
                 double *A, int LDA,
                 double *L, int LDL,
                 int *IPIV, double *WORK,
                 int LDWORK, int *INFO);
int CORE_dtplqt( int M, int N, int L, int IB,
                 double *A, int LDA,
                 double *B, int LDB,
                 double *T, int LDT,
                 double *WORK );
int CORE_dtpmlqt( cham_side_t side, cham_trans_t trans,
                  int M, int N, int K, int L, int IB,
                  const double *V, int LDV,
                  const double *T, int LDT,
                  double *A, int LDA,
                  double *B, int LDB,
                  double *WORK );
int CORE_dtpmqrt( cham_side_t side, cham_trans_t trans,
                  int M, int N, int K, int L, int IB,
                  const double *V, int LDV,
                  const double *T, int LDT,
                  double *A, int LDA,
                  double *B, int LDB,
                  double *WORK );
int CORE_dtpqrt( int M, int N, int L, int IB,
                 double *A, int LDA,
                 double *B, int LDB,
                 double *T, int LDT,
                 double *WORK );
int  CORE_dttmqr(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 const double *V, int LDV,
                 const double *T, int LDT,
                 double *WORK, int LDWORK);
int  CORE_dttqrt(int M, int N, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 double *T, int LDT,
                 double *TAU,
                 double *WORK);
int  CORE_dttmlq(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 const double *V, int LDV,
                 const double *T, int LDT,
                 double *WORK, int LDWORK);
int  CORE_dttlqt(int M, int N, int IB,
                 double *A1, int LDA1,
                 double *A2, int LDA2,
                 double *T, int LDT,
                 double *TAU,
                 double *WORK);
int  CORE_dormlq(cham_side_t side, cham_trans_t trans,
                 int M, int N, int IB, int K,
                 const double *V, int LDV,
                 const double *T, int LDT,
                 double *C, int LDC,
                 double *WORK, int LDWORK);
int  CORE_dormqr(cham_side_t side, cham_trans_t trans,
                 int M, int N, int K, int IB,
                 const double *V, int LDV,
                 const double *T, int LDT,
                 double *C, int LDC,
                 double *WORK, int LDWORK);

/**
 * Gram prototypes
 */
int CORE_dgram( cham_uplo_t uplo, int M, int N, int Mt, int Nt,
                const double *Di, int LDDI,
                const double *Dj, int LDDJ,
                const double *D,
                double *A, int LDA );

#endif /* _coreblas_d_h_ */
