/**
 *
 * @file coreblas_dtile.h
 *
 * @copyright 2019-2021 Bordeaux INP, CNRS (LaBRI UMR 5800 ), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 * @brief Chameleon CPU kernel CHAM_tile_t interface
 *
 * @version 1.1.0
 * @author Mathieu Faverge
 * @date 2020-10-12
 * @generated from /tmp/slackdce/slackrepo.gsXdbP/build_chameleon/chameleon-1.1.0/coreblas/include/coreblas/coreblas_ztile.h, normal z -> d, Sat May 10 04:39:42 2025
 *
 */
#ifndef _coreblas_dtile_h_
#define _coreblas_dtile_h_

#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_dlag2z_fake( cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
#endif
void TCORE_dasum( cham_store_t storev, cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, double *work );
int  TCORE_daxpy( int M, double alpha, const CHAM_tile_t *A, int incA, CHAM_tile_t *B, int incB );
int  TCORE_dgeadd( cham_trans_t trans, int M, int N, double alpha, const CHAM_tile_t *A, double beta, CHAM_tile_t *B );
int  TCORE_dgelqt( int M, int N, int IB, CHAM_tile_t *A, CHAM_tile_t *T, double *TAU, double *WORK );
void TCORE_dgemv( cham_trans_t trans, int M, int N, double alpha, const CHAM_tile_t *A, const CHAM_tile_t *x, int incx, double beta, CHAM_tile_t *y, int incy );
void TCORE_dgemm( cham_trans_t transA, cham_trans_t transB, int M, int N, int K, double alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, double beta, CHAM_tile_t *C );
int  TCORE_dgeqrt( int M, int N, int IB, CHAM_tile_t *A, CHAM_tile_t *T, double *TAU, double *WORK );
int  TCORE_dgessm( int M, int N, int K, int IB, const int *IPIV, const CHAM_tile_t *L, CHAM_tile_t *A );
int  TCORE_dgessq( cham_store_t storev, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
int  TCORE_dgetrf( int M, int N, CHAM_tile_t *A, int *IPIV, int *INFO );
int  TCORE_dgetrf_incpiv( int M, int N, int IB, CHAM_tile_t *A, int *IPIV, int *INFO );
int  TCORE_dgetrf_nopiv( int M, int N, int IB, CHAM_tile_t *A, int *INFO );
void TCORE_dhe2ge( cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_dsymm( cham_side_t side, cham_uplo_t uplo, int M, int N, double alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, double beta, CHAM_tile_t *C );
void TCORE_dsyrk( cham_uplo_t uplo, cham_trans_t trans, int N, int K, double alpha, const CHAM_tile_t *A, double beta, CHAM_tile_t *C );
void TCORE_dsyr2k( cham_uplo_t uplo, cham_trans_t trans, int N, int K, double alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, double beta, CHAM_tile_t *C );
#endif
int  TCORE_dsyrfb( cham_uplo_t uplo, int N, int K, int IB, int NB, const CHAM_tile_t *A, const CHAM_tile_t *T, CHAM_tile_t *C, double *WORK, int ldwork );
#if defined(PRECISION_z) || defined(PRECISION_c)
int  TCORE_dsyssq( cham_store_t storev, cham_uplo_t uplo, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
#endif
void TCORE_dlacpy( cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
void TCORE_dlange( cham_normtype_t norm, int M, int N, const CHAM_tile_t *A, double *work, double *normA );
#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_dlansy( cham_normtype_t norm, cham_uplo_t uplo, int N, const CHAM_tile_t *A, double *work, double *normA );
#endif
void TCORE_dlansy( cham_normtype_t norm, cham_uplo_t uplo, int N, const CHAM_tile_t *A, double *work, double *normA );
void TCORE_dlantr( cham_normtype_t norm, cham_uplo_t uplo, cham_diag_t diag, int M, int N, const CHAM_tile_t *A, double *work, double *normA );
int  TCORE_dlascal( cham_uplo_t uplo, int m, int n, double alpha, CHAM_tile_t *A );
void TCORE_dlaset( cham_uplo_t uplo, int n1, int n2, double alpha, double beta, CHAM_tile_t *A );
void TCORE_dlaset2( cham_uplo_t uplo, int n1, int n2, double alpha, CHAM_tile_t *A );
int  TCORE_dlatro( cham_uplo_t uplo, cham_trans_t trans, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
void TCORE_dlauum( cham_uplo_t uplo, int N, CHAM_tile_t *A );
#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_dplgsy( double bump, int m, int n, CHAM_tile_t *tileA, int bigM, int m0, int n0, unsigned long long int seed );
#endif
void TCORE_dplgsy( double bump, int m, int n, CHAM_tile_t *tileA, int bigM, int m0, int n0, unsigned long long int seed );
void TCORE_dplrnt( int m, int n, CHAM_tile_t *tileA, int bigM, int m0, int n0, unsigned long long int seed );
void TCORE_dpotrf( cham_uplo_t uplo, int n, CHAM_tile_t *A, int *INFO );
int  TCORE_dssssm( int M1, int N1, int M2, int N2, int K, int IB, CHAM_tile_t *A1, CHAM_tile_t *A2, const CHAM_tile_t *L1, const CHAM_tile_t *L2, const int *IPIV );
void TCORE_dsymm( cham_side_t side, cham_uplo_t uplo, int M, int N, double alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, double beta, CHAM_tile_t *C );
void TCORE_dsyrk( cham_uplo_t uplo, cham_trans_t trans, int N, int K, double alpha, const CHAM_tile_t *A, double beta, CHAM_tile_t *C );
void TCORE_dsyr2k( cham_uplo_t uplo, cham_trans_t trans, int N, int K, double alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, double beta, CHAM_tile_t *C );
int  TCORE_dsyssq( cham_store_t storev, cham_uplo_t uplo, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
int  TCORE_dsytf2_nopiv( cham_uplo_t uplo, int n, CHAM_tile_t *A );
int  TCORE_dtplqt( int M, int N, int L, int IB, CHAM_tile_t *A, CHAM_tile_t *B, CHAM_tile_t *T, double *WORK );
int  TCORE_dtpmlqt( cham_side_t side, cham_trans_t trans, int M, int N, int K, int L, int IB, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *A, CHAM_tile_t *B, double *WORK );
int  TCORE_dtpmqrt( cham_side_t side, cham_trans_t trans, int M, int N, int K, int L, int IB, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *A, CHAM_tile_t *B, double *WORK );
int  TCORE_dtpqrt( int M, int N, int L, int IB, CHAM_tile_t *A, CHAM_tile_t *B, CHAM_tile_t *T, double *WORK );
int  TCORE_dtradd( cham_uplo_t uplo, cham_trans_t trans, int M, int N, double alpha, const CHAM_tile_t *A, double beta, CHAM_tile_t *B );
void TCORE_dtrasm( cham_store_t storev, cham_uplo_t uplo, cham_diag_t diag, int M, int N, const CHAM_tile_t *A, double *work );
void TCORE_dtrmm( cham_side_t side, cham_uplo_t uplo, cham_trans_t transA, cham_diag_t diag, int M, int N, double alpha, const CHAM_tile_t *A, CHAM_tile_t *B );
void TCORE_dtrsm( cham_side_t side, cham_uplo_t uplo, cham_trans_t transA, cham_diag_t diag, int M, int N, double alpha, const CHAM_tile_t *A, CHAM_tile_t *B );
int  TCORE_dtrssq( cham_uplo_t uplo, cham_diag_t diag, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
void TCORE_dtrtri( cham_uplo_t uplo, cham_diag_t diag, int N, CHAM_tile_t *A, int *info );
int  TCORE_dtsmlq_hetra1( cham_side_t side, cham_trans_t trans, int m1, int n1, int m2, int n2, int k, int ib, CHAM_tile_t *A1, CHAM_tile_t *A2, const CHAM_tile_t *V, const CHAM_tile_t *T, double *WORK, int ldwork );
int  TCORE_dtsmqr_hetra1( cham_side_t side, cham_trans_t trans, int m1, int n1, int m2, int n2, int k, int ib, CHAM_tile_t *A1, CHAM_tile_t *A2, const CHAM_tile_t *V, const CHAM_tile_t *T, double *WORK, int ldwork );
int  TCORE_dtstrf( int M, int N, int IB, int NB, CHAM_tile_t *U, CHAM_tile_t *A, CHAM_tile_t *L, int *IPIV, double *WORK, int LDWORK, int *INFO );
int  TCORE_dormlq( cham_side_t side, cham_trans_t trans, int M, int N, int IB, int K, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *C, double *WORK, int LDWORK );
int  TCORE_dormqr( cham_side_t side, cham_trans_t trans, int M, int N, int K, int IB, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *C, double *WORK, int LDWORK );
int TCORE_dgram( cham_uplo_t uplo, int M, int N, int Mt, int Nt, const CHAM_tile_t *Di, const CHAM_tile_t *Dj, const CHAM_tile_t *D, CHAM_tile_t *A );

#endif /* _coreblas_dtile_h_ */
