/**
 *
 * @file coreblas_s.h
 *
 * @copyright 2009-2014 The University of Tennessee and The University of
 *                      Tennessee Research Foundation. All rights reserved.
 * @copyright 2012-2021 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 ***
 *
 * @brief Chameleon CPU float kernels header
 *
 * @version 1.1.0
 * @comment This file has been automatically generated
 *          from Plasma 2.5.0 for CHAMELEON 0.9.2
 * @author Jakub Kurzak
 * @author Hatem Ltaief
 * @author Azzam Haidar
 * @author Mathieu Faverge
 * @author Emmanuel Agullo
 * @author Cedric Castagnede
 * @author Florent Pruvost
 * @date 2020-10-12
 * @generated from /tmp/slackdce/slackrepo.gsXdbP/build_chameleon/chameleon-1.1.0/coreblas/include/coreblas/coreblas_z.h, normal z -> s, Sat May 10 04:39:42 2025
 *
 */
#ifndef _coreblas_s_h_
#define _coreblas_s_h_

/**
 *  Declarations of serial kernels - alphabetical order
 */
void CORE_slag2c_fake( cham_uplo_t uplo, int M, int N,
                  const float          *A, int lda,
                  float *B, int ldb );
void CORE_sasum(cham_store_t storev, cham_uplo_t uplo, int M, int N,
                 const float *A, int lda, float *work);
int CORE_saxpy(int M, float alpha,
               const float *A, int incA,
                     float *B, int incB);
int CORE_sgeadd(cham_trans_t trans, int M, int N,
                      float alpha,
                const float *A, int LDA,
                      float beta,
                      float *B, int LDB);
int CORE_slascal( cham_uplo_t uplo, int m, int n,
              float alpha, float *A, int lda );
int  CORE_sgelqt(int M, int N, int IB,
                 float *A, int LDA,
                 float *T, int LDT,
                 float *TAU,
                 float *WORK);
void CORE_sgemm(cham_trans_t transA, cham_trans_t transB,
                int M, int N, int K,
                float alpha, const float *A, int LDA,
                                          const float *B, int LDB,
                float beta,        float *C, int LDC);
void CORE_sgemv(cham_trans_t trans, int M, int N,
                float alpha, const float *A, int LDA,
                                             const float *x, int incX,
                float beta,        float *y, int incY);
int  CORE_sgeqrt(int M, int N, int IB,
                 float *A, int LDA,
                 float *T, int LDT,
                 float *TAU, float *WORK);
int CORE_sgesplit(cham_side_t side, cham_diag_t diag,
                  int M, int N,
                  float *A, int LDA,
                  float *B, int LDB);
int  CORE_sgessm(int M, int N, int K, int IB,
                 const int *IPIV,
                 const float *L, int LDL,
                 float *A, int LDA);
int  CORE_sgessq(cham_store_t storev, int M, int N,
                 const float *A, int LDA,
                 float *sclssq);
int CORE_sgetf2_nopiv(int M, int N,
                  float *A, int LDA);
int  CORE_sgetrf(int M, int N,
                 float *A, int LDA,
                 int *IPIV, int *INFO);
int  CORE_sgetrf_incpiv(int M, int N, int IB,
                        float *A, int LDA,
                        int *IPIV, int *INFO);
int CORE_sgetrf_nopiv(int M, int N, int IB,
                      float *A, int LDA,
                      int *INFO);
int  CORE_sgetrf_reclap(int M, int N,
                        float *A, int LDA,
                        int *IPIV, int *info);
int  CORE_sgetrf_rectil(const CHAM_desc_t A, int *IPIV, int *info);
void CORE_sgetrip(int m, int n, float *A,
                  float *work);
void CORE_she2ge(cham_uplo_t uplo, int M, int N,
                 const float *A, int LDA,
                 float *B, int LDB);
void CORE_ssygst(int itype, cham_uplo_t uplo, int N,
                 float *A, int LDA,
                 float *B, int LDB, int *INFO);
void CORE_ssymm(cham_side_t side, cham_uplo_t uplo,
                int M, int N,
                float alpha, const float *A, int LDA,
                                          const float *B, int LDB,
                float beta,        float *C, int LDC);
void CORE_ssyrk(cham_uplo_t uplo, cham_trans_t trans,
                int N, int K,
                float alpha, const float *A, int LDA,
                float beta,        float *C, int LDC);
void CORE_ssyr2k(cham_uplo_t uplo, cham_trans_t trans,
                 int N, int K,
                 float alpha, const float *A, int LDA,
                                           const float *B, int LDB,
                 float beta,                    float *C, int LDC);
int  CORE_ssyssq(cham_store_t storev, cham_uplo_t uplo, int N,
                 const float *A, int LDA,
                 float *sclssq);
int  CORE_ssyrfb(cham_uplo_t uplo, int N, int K, int IB, int NB,
                 const float *A,    int LDA,
                 const float *T,    int LDT,
                       float *C,    int LDC,
                       float *WORK, int LDWORK);
void CORE_slacpy(cham_uplo_t uplo, int M, int N,
                 const float *A, int LDA,
                       float *B, int LDB);
void CORE_slange(cham_normtype_t norm, int M, int N,
                 const float *A, int LDA,
                 float *work, float *normA);
void CORE_slansy(cham_normtype_t norm, cham_uplo_t uplo, int N,
                 const float *A, int LDA,
                 float *work, float *normA);
void CORE_slansy(cham_normtype_t norm, cham_uplo_t uplo, int N,
                 const float *A, int LDA,
                 float *work, float *normA);
void CORE_slantr(cham_normtype_t norm, cham_uplo_t uplo, cham_diag_t diag, int M, int N,
                 const float *A, int LDA,
                 float *work, float *normA);
int CORE_slarfb_gemm(cham_side_t side, cham_trans_t trans, cham_dir_t direct, cham_store_t storev,
                     int M, int N, int K,
                     const float *V, int LDV,
                     const float *T, int LDT,
                           float *C, int LDC,
                           float *WORK, int LDWORK);
int CORE_slarfx2(cham_side_t side, int N,
                 float V,
                 float TAU,
                 float *C1, int LDC1,
                 float *C2, int LDC2);
int CORE_slarfx2c(cham_uplo_t uplo,
                  float V,
                  float TAU,
                  float *C1,
                  float *C2,
                  float *C3);
int CORE_slarfx2ce(cham_uplo_t uplo,
                   float *V,
                   float *TAU,
                   float *C1,
                   float *C2,
                   float *C3);
void CORE_slarfy(int N,
                 float *A, int LDA,
                 const float *V,
                 const float *TAU,
                 float *WORK);
void CORE_slaset(cham_uplo_t uplo, int n1, int n2,
                 float alpha, float beta,
                 float *tileA, int ldtilea);
void CORE_slaset2(cham_uplo_t uplo, int n1, int n2, float alpha,
                  float *tileA, int ldtilea);
void CORE_slaswp(int N, float *A, int LDA,
                 int I1,  int I2, const int *IPIV, int INC);
int  CORE_slaswp_ontile( CHAM_desc_t descA, int i1, int i2, const int *ipiv, int inc);
int  CORE_slaswpc_ontile(CHAM_desc_t descA, int i1, int i2, const int *ipiv, int inc);
int  CORE_slatro(cham_uplo_t uplo, cham_trans_t trans,
                 int M, int N,
                 const float *A, int LDA,
                       float *B, int LDB);
int CORE_slatm1( int MODE, float COND, int IRSIGN, cham_dist_t DIST,
                 unsigned long long int seed,
                 float *D, int N );
void CORE_slauum(cham_uplo_t uplo, int N, float *A, int LDA);
int CORE_spamm(int op, cham_side_t side, cham_store_t storev,
               int M, int N, int K, int L,
               const float *A1, int LDA1,
                     float *A2, int LDA2,
               const float *V, int LDV,
                     float *W, int LDW);
int  CORE_sparfb(cham_side_t side, cham_trans_t trans, cham_dir_t direct, cham_store_t storev,
                 int M1, int N1, int M2, int N2, int K, int L,
                       float *A1, int LDA1,
                       float *A2, int LDA2,
                 const float *V, int LDV,
                 const float *T, int LDT,
                       float *WORK, int LDWORK);
int CORE_spemv(cham_trans_t trans, cham_store_t storev,
               int M, int N, int L,
               float ALPHA,
               const float *A, int LDA,
               const float *X, int INCX,
               float BETA,
               float *Y, int INCY,
               float *WORK);
void CORE_splgsy(float bump, int m, int n, float *A, int lda,
                 int bigM, int m0, int n0, unsigned long long int seed );
void CORE_splgsy(float bump, int m, int n, float *A, int lda,
                 int bigM, int m0, int n0, unsigned long long int seed );
void CORE_splrnt(int m, int n, float *A, int lda,
                 int bigM, int m0, int n0, unsigned long long int seed );
int CORE_splssq( cham_store_t storev, int M, int N,
                 float *sclssqin, float *sclssqout );
int CORE_splssq2( int N, float *sclssq );
void CORE_spotrf(cham_uplo_t uplo, int N, float *A, int LDA, int *INFO);
void CORE_sshift(int s, int m, int n, int L,
                 float *A);
void CORE_sshiftw(int s, int cl, int m, int n, int L,
                  float *A, float *W);
int  CORE_sssssm(int M1, int N1, int M2, int N2, int K, int IB,
                       float *A1, int LDA1,
                       float *A2, int LDA2,
                 const float *L1, int LDL1,
                 const float *L2, int LDL2,
                 const int *IPIV);
void CORE_ssymm(cham_side_t side, cham_uplo_t uplo,
                int M, int N,
                float alpha, const float *A, int LDA,
                                          const float *B, int LDB,
                float beta,        float *C, int LDC);
void CORE_ssyrk(cham_uplo_t uplo, cham_trans_t trans,
                int N, int K,
                float alpha, const float *A, int LDA,
                float beta,        float *C, int LDC);
void CORE_ssyr2k(cham_uplo_t uplo, cham_trans_t trans,
                 int N, int K,
                 float alpha, const float *A, int LDA,
                                           const float *B, int LDB,
                 float beta,        float *C, int LDC);
int  CORE_ssyssq(cham_store_t storev, cham_uplo_t uplo, int N,
                 const float *A, int LDA,
                 float *sclssq);
int CORE_ssytf2_nopiv(cham_uplo_t uplo, int n, float *A, int lda);
int CORE_stradd(cham_uplo_t uplo, cham_trans_t trans, int M, int N,
                      float alpha,
                const float *A, int LDA,
                      float beta,
                      float *B, int LDB);
void CORE_strasm(cham_store_t storev, cham_uplo_t uplo, cham_diag_t diag,
                 int M, int N,
                 const float *A, int lda, float *work);
void CORE_strmm(cham_side_t side, cham_uplo_t uplo,
                cham_trans_t transA, cham_diag_t diag,
                int M, int N,
                float alpha, const float *A, int LDA,
                                                float *B, int LDB);
void CORE_strsm(cham_side_t side, cham_uplo_t uplo,
                cham_trans_t transA, cham_diag_t diag,
                int M, int N,
                float alpha, const float *A, int LDA,
                                                float *B, int LDB);
int CORE_strssq(cham_uplo_t uplo, cham_diag_t diag, int M, int N,
                const float *A, int LDA,
                float *scale, float *sumsq);
void CORE_strtri(cham_uplo_t uplo, cham_diag_t diag, int N,
                 float *A, int LDA, int *info);
int  CORE_stslqt(int M, int N, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 float *T, int LDT,
                 float *TAU, float *WORK);
int  CORE_stsmlq(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 const float *V, int LDV,
                 const float *T, int LDT,
                 float *WORK, int LDWORK);
int CORE_stsmlq_hetra1( cham_side_t side, cham_trans_t trans,
                        int m1, int n1, int m2, int n2,
                        int k, int ib,
                        float *A1, int lda1,
                        float *A2, int lda2,
                        const float *V, int ldv,
                        const float *T, int ldt,
                        float *WORK, int ldwork);
int  CORE_stsmqr(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 const float *V, int LDV,
                 const float *T, int LDT,
                 float *WORK, int LDWORK);
int CORE_stsmqr_hetra1( cham_side_t side, cham_trans_t trans,
                        int m1, int n1, int m2, int n2,
                        int k, int ib,
                        float *A1, int lda1,
                        float *A2, int lda2,
                        const float *V, int ldv,
                        const float *T, int ldt,
                        float *WORK, int ldwork);
int  CORE_stsqrt(int M, int N, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 float *T, int LDT,
                 float *TAU, float *WORK);
int  CORE_ststrf(int M, int N, int IB, int NB,
                 float *U, int LDU,
                 float *A, int LDA,
                 float *L, int LDL,
                 int *IPIV, float *WORK,
                 int LDWORK, int *INFO);
int CORE_stplqt( int M, int N, int L, int IB,
                 float *A, int LDA,
                 float *B, int LDB,
                 float *T, int LDT,
                 float *WORK );
int CORE_stpmlqt( cham_side_t side, cham_trans_t trans,
                  int M, int N, int K, int L, int IB,
                  const float *V, int LDV,
                  const float *T, int LDT,
                  float *A, int LDA,
                  float *B, int LDB,
                  float *WORK );
int CORE_stpmqrt( cham_side_t side, cham_trans_t trans,
                  int M, int N, int K, int L, int IB,
                  const float *V, int LDV,
                  const float *T, int LDT,
                  float *A, int LDA,
                  float *B, int LDB,
                  float *WORK );
int CORE_stpqrt( int M, int N, int L, int IB,
                 float *A, int LDA,
                 float *B, int LDB,
                 float *T, int LDT,
                 float *WORK );
int  CORE_sttmqr(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 const float *V, int LDV,
                 const float *T, int LDT,
                 float *WORK, int LDWORK);
int  CORE_sttqrt(int M, int N, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 float *T, int LDT,
                 float *TAU,
                 float *WORK);
int  CORE_sttmlq(cham_side_t side, cham_trans_t trans,
                 int M1, int N1, int M2, int N2, int K, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 const float *V, int LDV,
                 const float *T, int LDT,
                 float *WORK, int LDWORK);
int  CORE_sttlqt(int M, int N, int IB,
                 float *A1, int LDA1,
                 float *A2, int LDA2,
                 float *T, int LDT,
                 float *TAU,
                 float *WORK);
int  CORE_sormlq(cham_side_t side, cham_trans_t trans,
                 int M, int N, int IB, int K,
                 const float *V, int LDV,
                 const float *T, int LDT,
                 float *C, int LDC,
                 float *WORK, int LDWORK);
int  CORE_sormqr(cham_side_t side, cham_trans_t trans,
                 int M, int N, int K, int IB,
                 const float *V, int LDV,
                 const float *T, int LDT,
                 float *C, int LDC,
                 float *WORK, int LDWORK);

/**
 * Gram prototypes
 */
int CORE_sgram( cham_uplo_t uplo, int M, int N, int Mt, int Nt,
                const float *Di, int LDDI,
                const float *Dj, int LDDJ,
                const float *D,
                float *A, int LDA );

#endif /* _coreblas_s_h_ */
