/**
 *
 * @file coreblas_stile.h
 *
 * @copyright 2019-2021 Bordeaux INP, CNRS (LaBRI UMR 5800 ), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 * @brief Chameleon CPU kernel CHAM_tile_t interface
 *
 * @version 1.1.0
 * @author Mathieu Faverge
 * @date 2020-10-12
 * @generated from /tmp/slackdce/slackrepo.gsXdbP/build_chameleon/chameleon-1.1.0/coreblas/include/coreblas/coreblas_ztile.h, normal z -> s, Sat May 10 04:39:42 2025
 *
 */
#ifndef _coreblas_stile_h_
#define _coreblas_stile_h_

#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_slag2c_fake( cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
#endif
void TCORE_sasum( cham_store_t storev, cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, float *work );
int  TCORE_saxpy( int M, float alpha, const CHAM_tile_t *A, int incA, CHAM_tile_t *B, int incB );
int  TCORE_sgeadd( cham_trans_t trans, int M, int N, float alpha, const CHAM_tile_t *A, float beta, CHAM_tile_t *B );
int  TCORE_sgelqt( int M, int N, int IB, CHAM_tile_t *A, CHAM_tile_t *T, float *TAU, float *WORK );
void TCORE_sgemv( cham_trans_t trans, int M, int N, float alpha, const CHAM_tile_t *A, const CHAM_tile_t *x, int incx, float beta, CHAM_tile_t *y, int incy );
void TCORE_sgemm( cham_trans_t transA, cham_trans_t transB, int M, int N, int K, float alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, float beta, CHAM_tile_t *C );
int  TCORE_sgeqrt( int M, int N, int IB, CHAM_tile_t *A, CHAM_tile_t *T, float *TAU, float *WORK );
int  TCORE_sgessm( int M, int N, int K, int IB, const int *IPIV, const CHAM_tile_t *L, CHAM_tile_t *A );
int  TCORE_sgessq( cham_store_t storev, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
int  TCORE_sgetrf( int M, int N, CHAM_tile_t *A, int *IPIV, int *INFO );
int  TCORE_sgetrf_incpiv( int M, int N, int IB, CHAM_tile_t *A, int *IPIV, int *INFO );
int  TCORE_sgetrf_nopiv( int M, int N, int IB, CHAM_tile_t *A, int *INFO );
void TCORE_she2ge( cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_ssymm( cham_side_t side, cham_uplo_t uplo, int M, int N, float alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, float beta, CHAM_tile_t *C );
void TCORE_ssyrk( cham_uplo_t uplo, cham_trans_t trans, int N, int K, float alpha, const CHAM_tile_t *A, float beta, CHAM_tile_t *C );
void TCORE_ssyr2k( cham_uplo_t uplo, cham_trans_t trans, int N, int K, float alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, float beta, CHAM_tile_t *C );
#endif
int  TCORE_ssyrfb( cham_uplo_t uplo, int N, int K, int IB, int NB, const CHAM_tile_t *A, const CHAM_tile_t *T, CHAM_tile_t *C, float *WORK, int ldwork );
#if defined(PRECISION_z) || defined(PRECISION_c)
int  TCORE_ssyssq( cham_store_t storev, cham_uplo_t uplo, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
#endif
void TCORE_slacpy( cham_uplo_t uplo, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
void TCORE_slange( cham_normtype_t norm, int M, int N, const CHAM_tile_t *A, float *work, float *normA );
#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_slansy( cham_normtype_t norm, cham_uplo_t uplo, int N, const CHAM_tile_t *A, float *work, float *normA );
#endif
void TCORE_slansy( cham_normtype_t norm, cham_uplo_t uplo, int N, const CHAM_tile_t *A, float *work, float *normA );
void TCORE_slantr( cham_normtype_t norm, cham_uplo_t uplo, cham_diag_t diag, int M, int N, const CHAM_tile_t *A, float *work, float *normA );
int  TCORE_slascal( cham_uplo_t uplo, int m, int n, float alpha, CHAM_tile_t *A );
void TCORE_slaset( cham_uplo_t uplo, int n1, int n2, float alpha, float beta, CHAM_tile_t *A );
void TCORE_slaset2( cham_uplo_t uplo, int n1, int n2, float alpha, CHAM_tile_t *A );
int  TCORE_slatro( cham_uplo_t uplo, cham_trans_t trans, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *B );
void TCORE_slauum( cham_uplo_t uplo, int N, CHAM_tile_t *A );
#if defined(PRECISION_z) || defined(PRECISION_c)
void TCORE_splgsy( float bump, int m, int n, CHAM_tile_t *tileA, int bigM, int m0, int n0, unsigned long long int seed );
#endif
void TCORE_splgsy( float bump, int m, int n, CHAM_tile_t *tileA, int bigM, int m0, int n0, unsigned long long int seed );
void TCORE_splrnt( int m, int n, CHAM_tile_t *tileA, int bigM, int m0, int n0, unsigned long long int seed );
void TCORE_spotrf( cham_uplo_t uplo, int n, CHAM_tile_t *A, int *INFO );
int  TCORE_sssssm( int M1, int N1, int M2, int N2, int K, int IB, CHAM_tile_t *A1, CHAM_tile_t *A2, const CHAM_tile_t *L1, const CHAM_tile_t *L2, const int *IPIV );
void TCORE_ssymm( cham_side_t side, cham_uplo_t uplo, int M, int N, float alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, float beta, CHAM_tile_t *C );
void TCORE_ssyrk( cham_uplo_t uplo, cham_trans_t trans, int N, int K, float alpha, const CHAM_tile_t *A, float beta, CHAM_tile_t *C );
void TCORE_ssyr2k( cham_uplo_t uplo, cham_trans_t trans, int N, int K, float alpha, const CHAM_tile_t *A, const CHAM_tile_t *B, float beta, CHAM_tile_t *C );
int  TCORE_ssyssq( cham_store_t storev, cham_uplo_t uplo, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
int  TCORE_ssytf2_nopiv( cham_uplo_t uplo, int n, CHAM_tile_t *A );
int  TCORE_stplqt( int M, int N, int L, int IB, CHAM_tile_t *A, CHAM_tile_t *B, CHAM_tile_t *T, float *WORK );
int  TCORE_stpmlqt( cham_side_t side, cham_trans_t trans, int M, int N, int K, int L, int IB, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *A, CHAM_tile_t *B, float *WORK );
int  TCORE_stpmqrt( cham_side_t side, cham_trans_t trans, int M, int N, int K, int L, int IB, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *A, CHAM_tile_t *B, float *WORK );
int  TCORE_stpqrt( int M, int N, int L, int IB, CHAM_tile_t *A, CHAM_tile_t *B, CHAM_tile_t *T, float *WORK );
int  TCORE_stradd( cham_uplo_t uplo, cham_trans_t trans, int M, int N, float alpha, const CHAM_tile_t *A, float beta, CHAM_tile_t *B );
void TCORE_strasm( cham_store_t storev, cham_uplo_t uplo, cham_diag_t diag, int M, int N, const CHAM_tile_t *A, float *work );
void TCORE_strmm( cham_side_t side, cham_uplo_t uplo, cham_trans_t transA, cham_diag_t diag, int M, int N, float alpha, const CHAM_tile_t *A, CHAM_tile_t *B );
void TCORE_strsm( cham_side_t side, cham_uplo_t uplo, cham_trans_t transA, cham_diag_t diag, int M, int N, float alpha, const CHAM_tile_t *A, CHAM_tile_t *B );
int  TCORE_strssq( cham_uplo_t uplo, cham_diag_t diag, int M, int N, const CHAM_tile_t *A, CHAM_tile_t *sclssq );
void TCORE_strtri( cham_uplo_t uplo, cham_diag_t diag, int N, CHAM_tile_t *A, int *info );
int  TCORE_stsmlq_hetra1( cham_side_t side, cham_trans_t trans, int m1, int n1, int m2, int n2, int k, int ib, CHAM_tile_t *A1, CHAM_tile_t *A2, const CHAM_tile_t *V, const CHAM_tile_t *T, float *WORK, int ldwork );
int  TCORE_stsmqr_hetra1( cham_side_t side, cham_trans_t trans, int m1, int n1, int m2, int n2, int k, int ib, CHAM_tile_t *A1, CHAM_tile_t *A2, const CHAM_tile_t *V, const CHAM_tile_t *T, float *WORK, int ldwork );
int  TCORE_ststrf( int M, int N, int IB, int NB, CHAM_tile_t *U, CHAM_tile_t *A, CHAM_tile_t *L, int *IPIV, float *WORK, int LDWORK, int *INFO );
int  TCORE_sormlq( cham_side_t side, cham_trans_t trans, int M, int N, int IB, int K, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *C, float *WORK, int LDWORK );
int  TCORE_sormqr( cham_side_t side, cham_trans_t trans, int M, int N, int K, int IB, const CHAM_tile_t *V, const CHAM_tile_t *T, CHAM_tile_t *C, float *WORK, int LDWORK );
int TCORE_sgram( cham_uplo_t uplo, int M, int N, int Mt, int Nt, const CHAM_tile_t *Di, const CHAM_tile_t *Dj, const CHAM_tile_t *D, CHAM_tile_t *A );

#endif /* _coreblas_stile_h_ */
